@@ -20,8 +20,8 @@ from multiprocessing.managers import SyncManager
 import pylab
 
 DESC = "A merger of genome alignments."
-VERSION = '0.2.3'
-PKG_VERSION = '0.2.3'
+VERSION = '0.2.4'
+PKG_VERSION = '0.2.4'
 
 #constant flags from the sam specs
 MULTIPLE_SEGMENT_FLAG = 1 << 0 #0x01
@@ -1715,7 +1715,7 @@ def getLogger():
 def performInputChecks(fnList):
     retHeader = None
     
-    for fn in fnList:
+    for i, fn in enumerate(fnList):
         bam = pysam.Samfile(fn, 'rb')
     
         currentHeader = dict(bam.header.items())
@@ -1730,9 +1730,9 @@ def performInputChecks(fnList):
             if currentHeader.has_key('PG'):
                 #set h2 to different keys before combining
                 for pg in currentHeader['PG']:
-                    pg['ID'] = pg['ID'] + ' #2'
+                    pg['ID'] = pg['ID'] + ' #'+str(i+1)
                     if pg.has_key('PP'):
-                        pg['PP'] = pg['PP'] + ' #2'
+                        pg['PP'] = pg['PP'] + ' #'+str(i+1)
                         
                 if retHeader.has_key('PG'):
                     #finally combine them
